@@ -1,27 +1,28 @@
+from autoconf.dictable import from_dict, from_json, output_to_json, to_dict
 from autoarray import preprocess
 from autoarray.dataset.imaging.w_tilde import WTildeImaging
-from autoarray.dataset.imaging.imaging import Imaging, SettingsImaging
-from autoarray.dataset.interferometer.interferometer import (
+from autoarray.dataset.imaging.dataset import Imaging
+from autoarray.dataset.interferometer.dataset import (
     Interferometer,
-    SettingsInterferometer,
 )
+from autoarray.dataset.dataset_model import DatasetModel
 from autoarray.mask.mask_1d import Mask1D
 from autoarray.mask.mask_2d import Mask2D
 from autoarray.operators.convolver import Convolver
+from autoarray.operators.over_sampling.uniform import OverSamplingUniform  # noqa
+from autoarray.operators.over_sampling.uniform import OverSamplerUniform  # noqa
+from autoarray.operators.over_sampling.iterate import OverSamplingIterate
+from autoarray.operators.over_sampling.iterate import OverSamplerIterate
+from autoarray.inversion.inversion.dataset_interface import DatasetInterface
+from autoarray.inversion.pixelization import image_mesh
 from autoarray.inversion.pixelization import mesh
 from autoarray.inversion import regularization as reg
+from autoarray.inversion.pixelization.image_mesh.abstract import AbstractImageMesh
 from autoarray.inversion.pixelization.mesh.abstract import AbstractMesh
 from autoarray.inversion.regularization.abstract import AbstractRegularization
 from autoarray.inversion.pixelization.pixelization import Pixelization
-from autoarray.inversion.pixelization.settings import SettingsPixelization
 from autoarray.inversion.inversion.settings import SettingsInversion
 from autoarray.inversion.inversion.factory import inversion_from as Inversion
-from autoarray.inversion.inversion.factory import (
-    inversion_imaging_unpacked_from as InversionImaging,
-)
-from autoarray.inversion.inversion.factory import (
-    inversion_interferometer_unpacked_from as InversionInterferometer,
-)
 from autoarray.inversion.pixelization.mappers.abstract import AbstractMapper
 from autoarray.inversion.pixelization.mappers.mapper_grids import MapperGrids
 from autoarray.inversion.pixelization.mappers.factory import mapper_from as Mapper
@@ -32,10 +33,9 @@ from autoarray.structures.arrays.uniform_2d import Array2D
 from autoarray.structures.arrays.irregular import ArrayIrregular
 from autoarray.structures.grids.uniform_1d import Grid1D
 from autoarray.structures.grids.uniform_2d import Grid2D
-from autoarray.structures.grids.sparse_2d import Grid2DSparse
-from autoarray.structures.grids.iterate_2d import Grid2DIterate
 from autoarray.structures.grids.irregular_2d import Grid2DIrregular
 from autoarray.structures.grids.irregular_2d import Grid2DIrregularUniform
+from autoarray.operators.over_sampling.iterate import OverSamplingIterate
 from autoarray.structures.mesh.rectangular_2d import Mesh2DRectangular
 from autoarray.structures.mesh.voronoi_2d import Mesh2DVoronoi
 from autoarray.structures.mesh.delaunay_2d import Mesh2DDelaunay
@@ -46,16 +46,17 @@ from autoarray.structures.visibilities import Visibilities
 from autoarray.structures.visibilities import VisibilitiesNoiseMap
 
 from autogalaxy import cosmology as cosmo
+from autogalaxy.analysis.adapt_images.adapt_images import AdaptImages
+from autogalaxy.analysis.adapt_images.adapt_image_maker import AdaptImageMaker
 from autogalaxy.gui.clicker import Clicker
 from autogalaxy.gui.scribbler import Scribbler
 from autogalaxy.galaxy.galaxy import Galaxy
+from autogalaxy.galaxy.galaxies import Galaxies
 from autogalaxy.galaxy.redshift import Redshift
 from autogalaxy.analysis.clump_model import ClumpModel
 from autogalaxy.analysis.clump_model import ClumpModelDisabled
 
 from autogalaxy.quantity.dataset_quantity import DatasetQuantity
-from autogalaxy.quantity.dataset_quantity import SettingsQuantity
-from autogalaxy.plane.plane import Plane
 from autogalaxy.profiles.geometry_profiles import EllProfile
 from autogalaxy.profiles import (
     point_sources as ps,
@@ -67,7 +68,6 @@ from autogalaxy.profiles.light.abstract import LightProfile
 from autogalaxy.profiles.light import standard as lp
 from autogalaxy.profiles.light import snr as lp_snr
 from autogalaxy.profiles.light import linear as lp_linear
-from autogalaxy.profiles.light import shapelets as lp_shapelets
 from autogalaxy.profiles.light import operated as lp_operated
 from autogalaxy.profiles.light import basis as lp_basis
 from autogalaxy.profiles.light import (
@@ -81,17 +81,15 @@ from autogalaxy import convert
 from . import plot
 from . import aggregator as agg
 from .lens import subhalo
-from .analysis.settings import SettingsLens
-from .lens.ray_tracing import Tracer
+from .lens.tracer import Tracer
 from .lens.to_inversion import TracerToInversion
 from .analysis.positions import PositionsLHResample
 from .analysis.positions import PositionsLHPenalty
 from .analysis.preloads import Preloads
-from .analysis.setup import SetupAdapt
-from .imaging.imaging import SimulatorImaging
+from .imaging.simulator import SimulatorImaging
 from .imaging.fit_imaging import FitImaging
 from .imaging.model.analysis import AnalysisImaging
-from .interferometer.interferometer import SimulatorInterferometer
+from .interferometer.simulator import SimulatorInterferometer
 from .interferometer.fit_interferometer import FitInterferometer
 from .interferometer.model.analysis import AnalysisInterferometer
 from .point.point_dataset import PointDataset
@@ -114,4 +112,4 @@ from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = "2023.7.5.2"
+__version__ = "2024.5.16.0"
