@@ -5,13 +5,14 @@ import os
 
 import autoarray as aa
 import autofit as af
+
 from autofit.tools.util import open_
 
 import autogalaxy as ag
 
-from autogalaxy.analysis.analysis import AnalysisDataset
+from autogalaxy.analysis.analysis.dataset import AnalysisDataset
 
-from autolens.lens.ray_tracing import Tracer
+from autolens.lens.tracer import Tracer
 from autolens.point.fit_point.max_separation import FitPositionsSourceMaxSeparation
 
 from autolens import exc
@@ -63,7 +64,7 @@ class AbstractPositionsLH:
         - The arc second coordinates of the lensed source multiple images used for the model-fit.
         - The radial distance of these coordinates from (0.0, 0.0).
         - The threshold value used by the likelihood penalty.
-        - The maximum source plane seperation of the maximum likelihood tracer.
+        - The maximum source plane separation of the maximum likelihood tracer.
 
         Parameters
         ----------
@@ -87,7 +88,7 @@ class AbstractPositionsLH:
             f.write(f"Radial Distance from (0.0, 0.0): \n {distances} \n\n")
             f.write(f"Threshold = {self.threshold} \n")
             f.write(
-                f"Max Source Plane Seperation of Maximum Likelihood Model = {positions_fit.max_separation_of_source_plane_positions}"
+                f"Max Source Plane Separation of Maximum Likelihood Model = {positions_fit.max_separation_of_source_plane_positions}"
             )
 
 
