@@ -39,15 +39,13 @@ def make_point_solver():
 
 
 def make_tracer_x1_plane_7x7():
-    return al.Tracer.from_galaxies(galaxies=[make_gal_x1_lp()])
+    return al.Tracer(galaxies=[make_gal_x1_lp()])
 
 
 def make_tracer_x2_plane_7x7():
     source_gal_x1_lp = al.Galaxy(redshift=1.0, light_profile_0=make_lp_0())
 
-    return al.Tracer.from_galaxies(
-        galaxies=[make_gal_x1_mp(), make_gal_x1_lp(), source_gal_x1_lp]
-    )
+    return al.Tracer(galaxies=[make_gal_x1_mp(), make_gal_x1_lp(), source_gal_x1_lp])
 
 
 def make_tracer_x2_plane_inversion_7x7():
@@ -57,19 +55,7 @@ def make_tracer_x2_plane_inversion_7x7():
 
     source_gal_inversion = al.Galaxy(redshift=1.0, pixelization=pixelization)
 
-    return al.Tracer.from_galaxies(
-        galaxies=[make_gal_x1_mp(), make_gal_x1_lp(), source_gal_inversion]
-    )
-
-
-def make_tracer_x2_plane_voronoi_7x7():
-    pixelization = al.Pixelization(
-        mesh=al.mesh.VoronoiMagnification(), regularization=al.reg.Constant()
-    )
-
-    source_gal_inversion = al.Galaxy(redshift=1.0, pixelization=pixelization)
-
-    return al.Tracer.from_galaxies(
+    return al.Tracer(
         galaxies=[make_gal_x1_mp(), make_gal_x1_lp(), source_gal_inversion]
     )
 
@@ -77,9 +63,7 @@ def make_tracer_x2_plane_voronoi_7x7():
 def make_tracer_x2_plane_point():
     source_gal_x1_lp = al.Galaxy(redshift=1.0, point_0=al.ps.PointFlux())
 
-    return al.Tracer.from_galaxies(
-        galaxies=[make_gal_x1_mp(), make_gal_x1_lp(), source_gal_x1_lp]
-    )
+    return al.Tracer(galaxies=[make_gal_x1_mp(), make_gal_x1_lp(), source_gal_x1_lp])
 
 
 def make_fit_imaging_x1_plane_7x7():
@@ -140,15 +124,46 @@ def make_fit_point_dict_x2_plane():
     )
 
 
-def make_analysis_imaging_7x7():
-    return al.AnalysisImaging(
-        dataset=make_masked_imaging_7x7(),
-        settings_inversion=aa.SettingsInversion(use_w_tilde=False),
+def make_adapt_galaxy_name_image_dict_7x7():
+    image_0 = ag.Array2D(
+        np.full(fill_value=2.0, shape=make_mask_2d_7x7().pixels_in_mask),
+        mask=make_mask_2d_7x7(),
+    )
+
+    image_1 = ag.Array2D(
+        np.full(fill_value=3.0, shape=make_mask_2d_7x7().pixels_in_mask),
+        mask=make_mask_2d_7x7(),
+    )
+
+    adapt_galaxy_name_image_dict = {
+        "('galaxies', 'lens')": image_0,
+        "('galaxies', 'source')": image_1,
+    }
+
+    return adapt_galaxy_name_image_dict
+
+
+def make_adapt_images_7x7():
+    return ag.AdaptImages(
+        galaxy_name_image_dict=make_adapt_galaxy_name_image_dict_7x7(),
     )
 
 
+def make_analysis_imaging_7x7():
+    analysis = al.AnalysisImaging(
+        dataset=make_masked_imaging_7x7(),
+        settings_inversion=aa.SettingsInversion(use_w_tilde=False),
+    )
+    analysis._adapt_images = make_adapt_images_7x7()
+    return analysis
+
+
 def make_analysis_interferometer_7():
-    return al.AnalysisInterferometer(dataset=make_interferometer_7())
+    analysis = al.AnalysisInterferometer(
+        dataset=make_interferometer_7(),
+    )
+    analysis._adapt_images = make_adapt_images_7x7()
+    return analysis
 
 
 def make_analysis_point_x2():
