@@ -1,3 +1,4 @@
+import copy
 import numpy as np
 from typing import Dict, List, Optional
 
@@ -9,7 +10,7 @@ import autogalaxy as ag
 from autogalaxy.abstract_fit import AbstractFitInversion
 
 from autolens.analysis.preloads import Preloads
-from autolens.lens.ray_tracing import Tracer
+from autolens.lens.tracer import Tracer
 from autolens.lens.to_inversion import TracerToInversion
 
 from autolens import exc
@@ -20,7 +21,8 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
         self,
         dataset: aa.Imaging,
         tracer: Tracer,
-        settings_pixelization: aa.SettingsPixelization = aa.SettingsPixelization(),
+        dataset_model : Optional[aa.DatasetModel] = None,
+        adapt_images: Optional[ag.AdaptImages] = None,
         settings_inversion: aa.SettingsInversion = aa.SettingsInversion(),
         preloads: Preloads = Preloads(),
         run_time_dict: Optional[Dict] = None,
@@ -55,27 +57,29 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
             The imaging dataset which is fitted by the galaxies in the tracer.
         tracer
             The tracer of galaxies whose light profile images are used to fit the imaging data.
-        settings_pixelization
-            Settings controlling how a pixelization is fitted for example if a border is used when creating the
-            pixelization.
+        dataset_model
+            Attributes which allow for parts of a dataset to be treated as a model (e.g. the background sky level).
+        adapt_images
+            Contains the adapt-images which are used to make a pixelization's mesh and regularization adapt to the
+            reconstructed galaxy's morphology.
         settings_inversion
             Settings controlling how an inversion is fitted for example which linear algebra formalism is used.
         preloads
             Contains preloaded calculations (e.g. linear algebra matrices) which can skip certain calculations in
             the fit.
         run_time_dict
-            A dictionary which if passed to the fit records how long fucntion calls which have the `profile_func`
+            A dictionary which if passed to the fit records how long function calls which have the `profile_func`
             decorator take to run.
         """
 
-        super().__init__(dataset=dataset, run_time_dict=run_time_dict)
+        super().__init__(dataset=dataset, dataset_model=dataset_model, run_time_dict=run_time_dict)
         AbstractFitInversion.__init__(
             self=self, model_obj=tracer, settings_inversion=settings_inversion
         )
 
         self.tracer = tracer
 
-        self.settings_pixelization = settings_pixelization
+        self.adapt_images = adapt_images
         self.settings_inversion = settings_inversion
 
         self.preloads = preloads
@@ -92,10 +96,11 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
         if self.preloads.blurred_image is None:
 
             return self.tracer.blurred_image_2d_from(
-                grid=self.dataset.grid,
+                grid=self.grid,
                 convolver=self.dataset.convolver,
-                blurring_grid=self.dataset.blurring_grid,
+                blurring_grid=self.blurring_grid,
             )
+
         return self.preloads.blurred_image
 
     @property
@@ -103,20 +108,31 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
         """
         Returns the dataset's image with all blurred light profile images in the fit's tracer subtracted.
         """
-        return self.image - self.blurred_image
+
+        return self.data - self.blurred_image
 
     @property
     def tracer_to_inversion(self) -> TracerToInversion:
 
-        return TracerToInversion(
-            tracer=self.tracer,
-            dataset=self.dataset,
+        dataset = aa.DatasetInterface(
             data=self.profile_subtracted_image,
             noise_map=self.noise_map,
+            convolver=self.dataset.convolver,
             w_tilde=self.w_tilde,
-            settings_pixelization=self.settings_pixelization,
+            grid=self.grid,
+            grid_pixelization=self.grid_pixelization,
+            blurring_grid=self.blurring_grid,
+            border_relocator=self.dataset.border_relocator,
+        )
+
+
+        return TracerToInversion(
+            dataset=dataset,
+            tracer=self.tracer,
+            adapt_images=self.adapt_images,
             settings_inversion=self.settings_inversion,
             preloads=self.preloads,
+            run_time_dict=self.run_time_dict
         )
 
     @cached_property
@@ -150,10 +166,6 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
 
         return self.blurred_image
 
-    @property
-    def grid(self) -> aa.type.Grid2DLike:
-        return self.dataset.grid
-
     @property
     def galaxy_model_image_dict(self) -> Dict[ag.Galaxy, np.ndarray]:
         """
@@ -168,10 +180,11 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
         For modeling, this dictionary is used to set up the `adapt_images` that adaptmodel_images_of_planes_list
         certain pixelizations to the data being fitted.
         """
+
         galaxy_blurred_image_2d_dict = self.tracer.galaxy_blurred_image_2d_dict_from(
             grid=self.grid,
             convolver=self.dataset.convolver,
-            blurring_grid=self.dataset.blurring_grid,
+            blurring_grid=self.blurring_grid,
         )
 
         galaxy_linear_obj_image_dict = self.galaxy_linear_obj_data_dict_from(
@@ -180,6 +193,48 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
 
         return {**galaxy_blurred_image_2d_dict, **galaxy_linear_obj_image_dict}
 
+    @property
+    def subtracted_images_of_galaxies_dict(self) -> Dict[ag.Galaxy, np.ndarray]:
+        """
+        A dictionary which associates every galaxy in the tracer with its `subtracted image`.
+
+        A subtracted image of a galaxy is the data where all other galaxy images are subtracted from it, therefore
+        showing how a galaxy appears in the data in the absence of all other galaxies.
+
+        This is used to visualize the contribution of each galaxy in the data.
+        """
+
+        subtracted_images_of_galaxies_dict = {}
+
+        for (galaxy, galaxy_model_image) in self.galaxy_model_image_dict.items():
+            subtracted_images_of_galaxies_dict[galaxy] = copy.copy(self.dataset.data)
+
+        for (galaxy, galaxy_model_image) in self.galaxy_model_image_dict.items():
+            for (galaxy_other, galaxy_model_image_other) in self.galaxy_model_image_dict.items():
+                if galaxy != galaxy_other:
+                    subtracted_images_of_galaxies_dict[galaxy] -= galaxy_model_image_other
+
+        return subtracted_images_of_galaxies_dict
+
+    @property
+    def subtracted_signal_to_noise_maps_of_galaxies_dict(self) -> Dict[ag.Galaxy, np.ndarray]:
+        """
+        A dictionary which associates every galaxy in the tracer with its `subtracted image`.
+
+        A subtracted image of a galaxy is the data where all other galaxy images are subtracted from it, therefore
+        showing how a galaxy appears in the data in the absence of all other galaxies.
+
+        This is used to visualize the contribution of each galaxy in the data.
+        """
+
+        subtracted_signal_to_noise_maps_of_galaxies_dict = {}
+
+        for (galaxy, subtracted_image) in self.subtracted_images_of_galaxies_dict.items():
+
+            subtracted_signal_to_noise_maps_of_galaxies_dict[galaxy] = subtracted_image / self.noise_map
+
+        return subtracted_signal_to_noise_maps_of_galaxies_dict
+
     @property
     def model_images_of_planes_list(self) -> List[aa.Array2D]:
         """
@@ -198,13 +253,13 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
 
         model_images_of_planes_list = [
             aa.Array2D(
-            values=np.zeros(self.dataset.grid.shape_slim), mask=self.dataset.mask
+            values=np.zeros(self.grid.shape_slim), mask=self.dataset.mask
             )
             for i in range(self.tracer.total_planes)
         ]
 
-        for plane_index, plane in enumerate(self.tracer.planes):
-            for galaxy in plane.galaxies:
+        for plane_index, galaxies in enumerate(self.tracer.planes):
+            for galaxy in galaxies:
                 model_images_of_planes_list[plane_index] += galaxy_model_image_dict[
                     galaxy
                 ]
@@ -236,7 +291,7 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
                 if i != galaxy_index
             ]
 
-            subtracted_image = self.image - sum(other_planes_model_images)
+            subtracted_image = self.data - sum(other_planes_model_images)
 
             subtracted_images_of_planes_list.append(subtracted_image)
 
@@ -318,8 +373,9 @@ class FitImaging(aa.FitImaging, AbstractFitInversion):
         return FitImaging(
             dataset=self.dataset,
             tracer=self.tracer,
-            settings_pixelization=self.settings_pixelization,
+            dataset_model=self.dataset_model,
+            adapt_images=self.adapt_images,
             settings_inversion=settings_inversion,
             preloads=preloads,
             run_time_dict=run_time_dict,
-        )
+        )
\ No newline at end of file
