@@ -23,13 +23,21 @@ class MockFitImaging(aa.m.MockFitImaging):
             blurred_image=blurred_image,
         )
 
+        self._grid = grid
         self.tracer = tracer
-        self.grid = grid
+
+    @property
+    def grid(self):
+
+        if self._grid is not None:
+            return self._grid
+
+        return super().grid
 
     @property
     def tracer_to_inversion(self) -> MockTracerToInversion:
 
         return MockTracerToInversion(
             tracer=self.tracer,
-            sparse_image_plane_grid_pg_list=self.tracer.sparse_image_plane_grid_pg_list,
+            image_plane_mesh_grid_pg_list=self.tracer.image_plane_mesh_grid_pg_list,
         )
