@@ -1,6 +1,9 @@
+import copy
 import numpy as np
 from typing import Optional
 
+from autoconf import conf
+
 import autoarray as aa
 import autogalaxy.plot as aplt
 
@@ -9,7 +12,7 @@ from autoarray.fit.plot.fit_imaging_plotters import FitImagingPlotterMeta
 
 from autolens.plot.abstract_plotters import Plotter
 from autolens.imaging.fit_imaging import FitImaging
-from autolens.lens.plot.ray_tracing_plotters import TracerPlotter
+from autolens.lens.plot.tracer_plotters import TracerPlotter
 
 
 class FitImagingPlotter(Plotter):
@@ -76,9 +79,18 @@ class FitImagingPlotter(Plotter):
         """
         Returns an `TracerPlotter` corresponding to the `Tracer` in the `FitImaging`.
         """
+
+        extent = self.fit.data.extent_of_zoomed_array(buffer=0)
+        shape_native = self.fit.data.zoomed_around_mask(buffer=0).shape_native
+
+        grid = aa.Grid2D.from_extent(
+            extent=extent,
+            shape_native=shape_native
+        )
+
         return TracerPlotter(
             tracer=self.tracer,
-            grid=self.fit.grid,
+            grid=grid,
             mat_plot_2d=self.mat_plot_2d,
             visuals_2d=self.visuals_2d,
             include_2d=self.include_2d,
@@ -193,12 +205,27 @@ class FitImagingPlotter(Plotter):
 
             if subtracted_image:
 
+                title = f"Subtracted Image of Plane {plane_index}"
+                filename = f"subtracted_image_of_plane_{plane_index}"
+
+                if len(self.tracer.planes) == 2:
+
+                    if plane_index == 0:
+
+                        title = "Source Subtracted Image"
+                        filename = "source_subtracted_image"
+
+                    elif plane_index == 1:
+
+                        title = "Lens Subtracted Image"
+                        filename = "lens_subtracted_image"
+
                 self.mat_plot_2d.plot_array(
                     array=self.fit.subtracted_images_of_planes_list[plane_index],
                     visuals_2d=visuals_2d_no_critical_caustic,
                     auto_labels=aplt.AutoLabels(
-                        title=f"Subtracted Image of Plane {plane_index}",
-                        filename=f"subtracted_image_of_plane_{plane_index}",
+                        title=title,
+                        filename=filename
                     ),
                 )
 
@@ -214,12 +241,27 @@ class FitImagingPlotter(Plotter):
 
                     visuals_2d_model_image = visuals_2d
 
+                title = f"Model Image of Plane {plane_index}"
+                filename = f"model_image_of_plane_{plane_index}"
+
+                if len(self.tracer.planes) == 2:
+
+                    if plane_index == 0:
+
+                        title = "Lens Model Image"
+                        filename = "lens_model_image"
+
+                    elif plane_index == 1:
+
+                        title = "Source Model Image"
+                        filename = "source_model_image"
+
                 self.mat_plot_2d.plot_array(
                     array=self.fit.model_images_of_planes_list[plane_index],
                     visuals_2d=visuals_2d_model_image,
                     auto_labels=aplt.AutoLabels(
-                        title=f"Model Image of Plane {plane_index}",
-                        filename=f"model_image_of_plane_{plane_index}",
+                        title=title,
+                        filename=filename
                     ),
                 )
 
@@ -403,6 +445,212 @@ class FitImagingPlotter(Plotter):
         )
         self.close_subplot_figure()
 
+    def subplot_fit_log10(self):
+        """
+        Standard subplot of the attributes of the plotter's `FitImaging` object.
+        """
+
+        contour_original = copy.copy(self.mat_plot_2d.contour)
+        use_log10_original = self.mat_plot_2d.use_log10
+
+        self.open_subplot_figure(number_subplots=12)
+
+        self.mat_plot_2d.contour = False
+        self.mat_plot_2d.use_log10 = True
+
+        self.figures_2d(data=True)
+
+        self.set_title(label="Data (Source Scale)")
+
+        try:
+            self.figures_2d(data=True, use_source_vmax=True)
+        except ValueError:
+            pass
+
+        self.set_title(label=None)
+
+        try:
+            self.figures_2d(signal_to_noise_map=True)
+        except ValueError:
+            pass
+
+        self.figures_2d(model_image=True)
+
+        self.set_title(label="Lens Light Model Image")
+        self.figures_2d_of_planes(plane_index=0, model_image=True)
+
+        # If the lens light is not included the subplot index does not increase, so we must manually set it to 4
+        self.mat_plot_2d.subplot_index = 6
+
+        final_plane_index = len(self.fit.tracer.planes) - 1
+
+        self.mat_plot_2d.cmap.kwargs["vmin"] = 0.0
+
+        self.set_title(label="Lens Light Subtracted Image")
+        self.figures_2d_of_planes(plane_index=final_plane_index, subtracted_image=True, use_source_vmax=True)
+
+        self.set_title(label="Source Model Image (Image Plane)")
+        self.figures_2d_of_planes(plane_index=final_plane_index, model_image=True, use_source_vmax=True)
+
+        self.mat_plot_2d.cmap.kwargs.pop("vmin")
+
+        self.set_title(label="Source Plane (Zoomed)")
+        self.figures_2d_of_planes(plane_index=final_plane_index, plane_image=True, use_source_vmax=True)
+
+
+        self.set_title(label=None)
+
+        self.mat_plot_2d.use_log10 = False
+
+        self.mat_plot_2d.subplot_index = 9
+
+        self.figures_2d(normalized_residual_map=True)
+
+        self.mat_plot_2d.cmap.kwargs["vmin"] = -1.0
+        self.mat_plot_2d.cmap.kwargs["vmax"] = 1.0
+
+        self.set_title(label="Normalized Residual Map (1 sigma)")
+        self.figures_2d(normalized_residual_map=True)
+        self.set_title(label=None)
+
+        self.mat_plot_2d.cmap.kwargs.pop("vmin")
+        self.mat_plot_2d.cmap.kwargs.pop("vmax")
+
+        self.mat_plot_2d.use_log10 = True
+
+        self.figures_2d(chi_squared_map=True)
+
+        self.set_title(label="Source Plane (No Zoom)")
+        self.figures_2d_of_planes(
+            plane_index=final_plane_index,
+            plane_image=True,
+            zoom_to_brightest=False,
+            use_source_vmax=True
+        )
+
+        self.set_title(label=None)
+
+        self.mat_plot_2d.output.subplot_to_figure(
+            auto_filename="subplot_fit_log10"
+        )
+        self.close_subplot_figure()
+
+        self.mat_plot_2d.use_log10 = use_log10_original
+        self.mat_plot_2d.contour = contour_original
+
+    def subplot_tracer(self):
+        """
+        Standard subplot of a Tracer.
+
+        The `subplot_tracer` method in the `Tracer` class cannot plot the images of galaxies which are computed
+        via an `Inversion`. Therefore, using the `subplot_tracer` method of the `FitImagingPLotter` can plot
+        more information.
+
+        Returns
+        -------
+
+        """
+        use_log10_original = self.mat_plot_2d.use_log10
+
+        final_plane_index = len(self.fit.tracer.planes) - 1
+
+        self.open_subplot_figure(number_subplots=9)
+
+        self.figures_2d(model_image=True)
+
+        self.set_title(label="Lensed Source Image")
+        self.figures_2d_of_planes(plane_index=final_plane_index, model_image=True, use_source_vmax=True)
+        self.set_title(label=None)
+
+        self.set_title(label="Source Plane")
+        self.figures_2d_of_planes(
+            plane_index=final_plane_index,
+            plane_image=True,
+            zoom_to_brightest=False,
+            use_source_vmax=True
+        )
+
+        tracer_plotter = self.tracer_plotter
+
+        include_tangential_critical_curves_original = tracer_plotter.include_2d._tangential_critical_curves
+        include_radial_critical_curves_original = tracer_plotter.include_2d._radial_critical_curves
+
+        tracer_plotter._subplot_lens_and_mass()
+
+        self.mat_plot_2d.output.subplot_to_figure(
+            auto_filename="subplot_tracer"
+        )
+        self.close_subplot_figure()
+
+        self.include_2d._tangential_critical_curves = include_tangential_critical_curves_original
+        self.include_2d._radial_critical_curves = include_radial_critical_curves_original
+        self.mat_plot_2d.use_log10 = use_log10_original
+
+    def subplot_mappings_of_plane(self, plane_index: Optional[int] = None, auto_filename: str = "subplot_mappings"):
+
+        if not self.fit.inversion.has(cls=aa.Pixelization):
+            return
+
+        plane_indexes = self.plane_indexes_from(plane_index=plane_index)
+
+        for plane_index in plane_indexes:
+            
+            pixelization_index = 0
+
+            inversion_plotter = self.inversion_plotter_of_plane(plane_index=0)
+
+            inversion_plotter.open_subplot_figure(number_subplots=4)
+
+            inversion_plotter.figures_2d_of_pixelization(
+                pixelization_index=pixelization_index, data_subtracted=True
+            )
+
+            total_pixels = conf.instance["visualize"]["general"]["inversion"][
+                "total_mappings_pixels"
+            ]
+
+            pix_indexes = inversion_plotter.inversion.brightest_pixel_list_from(
+                total_pixels=total_pixels, filter_neighbors=True
+            )
+
+            inversion_plotter.visuals_2d.pix_indexes = [
+                [index] for index in pix_indexes[pixelization_index]
+            ]
+
+            inversion_plotter.visuals_2d.tangential_critical_curves = None
+            inversion_plotter.visuals_2d.radial_critical_curves = None
+
+            inversion_plotter.figures_2d_of_pixelization(
+                pixelization_index=pixelization_index, reconstructed_image=True
+            )
+
+            self.visuals_2d.pix_indexes = [
+                [index] for index in pix_indexes[pixelization_index]
+            ]
+
+            self.figures_2d_of_planes(
+                plane_index=plane_index,
+                plane_image=True,
+                use_source_vmax=True
+            )
+
+            self.set_title(label="Source Reconstruction (Unzoomed)")
+            self.figures_2d_of_planes(
+                plane_index=plane_index,
+                plane_image=True,
+                zoom_to_brightest=False,
+                use_source_vmax=True
+            )
+            self.set_title(label=None)
+
+            self.visuals_2d.pix_indexes = None
+
+            inversion_plotter.mat_plot_2d.output.subplot_to_figure(
+                auto_filename=f"{auto_filename}_{pixelization_index}"
+            )
+
+            inversion_plotter.close_subplot_figure()
+
     def figures_2d(
         self,
         data: bool = False,
@@ -412,6 +660,7 @@ class FitImagingPlotter(Plotter):
         residual_map: bool = False,
         normalized_residual_map: bool = False,
         chi_squared_map: bool = False,
+        residual_flux_fraction_map: bool = False,
         use_source_vmax : bool = False,
         suffix: str = "",
     ):
@@ -437,6 +686,8 @@ class FitImagingPlotter(Plotter):
             Whether to make a 2D plot (via `imshow`) of the normalized residual map.
         chi_squared_map
             Whether to make a 2D plot (via `imshow`) of the chi-squared map.
+        residual_flux_fraction_map
+            Whether to make a 2D plot (via `imshow`) of the residual flux fraction map.
         use_source_vmax
             If `True`, the maximum value of the lensed source (e.g. in the image-plane) is used to set the `vmax` of
             certain plots (e.g. the `data`) in order to ensure the lensed source is visible compared to the lens.
@@ -507,7 +758,7 @@ class FitImagingPlotter(Plotter):
 
         if self.residuals_symmetric_cmap:
 
-            self.mat_plot_2d.cmap = self.mat_plot_2d.cmap.symmetric
+            self.mat_plot_2d.cmap = self.mat_plot_2d.cmap.symmetric_cmap_from()
 
         if residual_map:
 
@@ -541,4 +792,14 @@ class FitImagingPlotter(Plotter):
                 auto_labels=AutoLabels(
                     title="Chi-Squared Map", cb_unit=r" $\chi^2$",  filename=f"chi_squared_map{suffix}"
                 ),
+            )
+
+        if residual_flux_fraction_map:
+
+            self.mat_plot_2d.plot_array(
+                array=self.fit.residual_flux_fraction_map,
+                visuals_2d=visuals_2d_no_critical_caustic,
+                auto_labels=AutoLabels(
+                    title="Residual Flux Fraction Map", filename=f"residual_flux_fraction_map{suffix}"
+                ),
             )
\ No newline at end of file
