@@ -9,7 +9,7 @@ import autogalaxy as ag
 from autogalaxy.abstract_fit import AbstractFitInversion
 
 from autolens.analysis.preloads import Preloads
-from autolens.lens.ray_tracing import Tracer
+from autolens.lens.tracer import Tracer
 from autolens.lens.to_inversion import TracerToInversion
 
 
@@ -18,7 +18,8 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         self,
         dataset: aa.Interferometer,
         tracer: Tracer,
-        settings_pixelization: aa.SettingsPixelization = aa.SettingsPixelization(),
+        dataset_model: Optional[aa.DatasetModel] = None,
+        adapt_images: Optional[ag.AdaptImages] = None,
         settings_inversion: aa.SettingsInversion = aa.SettingsInversion(),
         preloads: Preloads = Preloads(),
         run_time_dict: Optional[Dict] = None,
@@ -54,16 +55,18 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
             The interforometer dataset which is fitted by the galaxies in the tracer.
         tracer
             The tracer of galaxies whose light profile images are used to fit the interferometer data.
-        settings_pixelization
-            Settings controlling how a pixelization is fitted for example if a border is used when creating the
-            pixelization.
+        dataset_model
+            Attributes which allow for parts of a dataset to be treated as a model (e.g. the background sky level).
+        adapt_images
+            Contains the adapt-images which are used to make a pixelization's mesh and regularization adapt to the
+            reconstructed galaxy's morphology.
         settings_inversion
             Settings controlling how an inversion is fitted for example which linear algebra formalism is used.
         preloads
             Contains preloaded calculations (e.g. linear algebra matrices) which can skip certain calculations in
             the fit.
         run_time_dict
-            A dictionary which if passed to the fit records how long fucntion calls which have the `profile_func`
+            A dictionary which if passed to the fit records how long function calls which have the `profile_func`
             decorator take to run.
         """
 
@@ -74,14 +77,17 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
 
         self.tracer = tracer
 
-        self.settings_pixelization = settings_pixelization
+        self.adapt_images = adapt_images
+
         self.settings_inversion = settings_inversion
 
         self.preloads = preloads
 
         self.run_time_dict = run_time_dict
 
-        super().__init__(dataset=dataset, run_time_dict=run_time_dict)
+        super().__init__(
+            dataset=dataset, dataset_model=dataset_model, run_time_dict=run_time_dict
+        )
         AbstractFitInversion.__init__(
             self=self, model_obj=tracer, settings_inversion=settings_inversion
         )
@@ -93,7 +99,7 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         transform to the sum of light profile images.
         """
         return self.tracer.visibilities_from(
-            grid=self.dataset.grid, transformer=self.dataset.transformer
+            grid=self.grid, transformer=self.dataset.transformer
         )
 
     @property
@@ -102,17 +108,24 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         Returns the interferometer dataset's visibilities with all transformed light profile images in the fit's
         tracer subtracted.
         """
-        return self.visibilities - self.profile_visibilities
+        return self.data - self.profile_visibilities
 
     @property
     def tracer_to_inversion(self) -> TracerToInversion:
-        return TracerToInversion(
-            tracer=self.tracer,
-            dataset=self.dataset,
+        dataset = aa.DatasetInterface(
             data=self.profile_subtracted_visibilities,
             noise_map=self.noise_map,
+            transformer=self.dataset.transformer,
             w_tilde=self.w_tilde,
-            settings_pixelization=self.settings_pixelization,
+            grid=self.grid,
+            grid_pixelization=self.grid_pixelization,
+            border_relocator=self.dataset.border_relocator,
+        )
+
+        return TracerToInversion(
+            dataset=dataset,
+            tracer=self.tracer,
+            adapt_images=self.adapt_images,
             settings_inversion=self.settings_inversion,
             preloads=self.preloads,
         )
@@ -146,10 +159,6 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
 
         return self.profile_visibilities
 
-    @property
-    def grid(self) -> aa.type.Grid2DLike:
-        return self.dataset.grid
-
     @property
     def galaxy_model_image_dict(self) -> Dict[ag.Galaxy, np.ndarray]:
         """
@@ -185,7 +194,7 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
           are solved for first via the inversion.
         """
         galaxy_model_visibilities_dict = self.tracer.galaxy_visibilities_dict_from(
-            grid=self.dataset.grid, transformer=self.dataset.transformer
+            grid=self.grid, transformer=self.dataset.transformer
         )
 
         galaxy_linear_obj_visibilities_dict = self.galaxy_linear_obj_data_dict_from(
@@ -211,12 +220,12 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         galaxy_model_visibilities_dict = self.galaxy_model_visibilities_dict
 
         model_visibilities_of_planes_list = [
-            aa.Visibilities.zeros(shape_slim=(self.dataset.visibilities.shape_slim,))
+            aa.Visibilities.zeros(shape_slim=(self.dataset.data.shape_slim,))
             for i in range(self.tracer.total_planes)
         ]
 
-        for plane_index, plane in enumerate(self.tracer.planes):
-            for galaxy in plane.galaxies:
+        for plane_index, galaxies in enumerate(self.tracer.planes):
+            for galaxy in galaxies:
                 model_visibilities_of_planes_list[
                     plane_index
                 ] += galaxy_model_visibilities_dict[galaxy]
@@ -266,9 +275,10 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
             settings_inversion = self.settings_inversion
 
         return FitInterferometer(
-            dataset=self.interferometer,
+            dataset=self.dataset,
             tracer=self.tracer,
-            settings_pixelization=self.settings_pixelization,
+            dataset_model=self.dataset_model,
+            adapt_images=self.adapt_images,
             settings_inversion=settings_inversion,
             preloads=preloads,
             run_time_dict=run_time_dict,
