@@ -1,13 +1,15 @@
 from typing import Optional
 
+from autoconf import conf
+
 import autoarray as aa
 import autogalaxy.plot as aplt
 
 from autoarray.fit.plot.fit_interferometer_plotters import FitInterferometerPlotterMeta
 
 from autolens.interferometer.fit_interferometer import FitInterferometer
-from autolens.lens.ray_tracing import Tracer
-from autolens.lens.plot.ray_tracing_plotters import TracerPlotter
+from autolens.lens.tracer import Tracer
+from autolens.lens.plot.tracer_plotters import TracerPlotter
 from autolens.plot.abstract_plotters import Plotter
 
 
@@ -88,6 +90,25 @@ class FitInterferometerPlotter(Plotter):
     def get_visuals_2d_real_space(self) -> aplt.Visuals2D:
         return self.get_2d.via_mask_from(mask=self.fit.dataset.real_space_mask)
 
+    def plane_indexes_from(self, plane_index: int):
+        """
+        Returns a list of all indexes of the planes in the fit, which is iterated over in figures that plot
+        individual figures of each plane in a tracer.
+
+        Parameters
+        ----------
+        plane_index
+            A specific plane index which when input means that only a single plane index is returned.
+
+        Returns
+        -------
+        list
+            A list of galaxy indexes corresponding to planes in the plane.
+        """
+        if plane_index is None:
+            return range(len(self.fit.tracer.planes))
+        return [plane_index]
+
     @property
     def tracer(self) -> Tracer:
         return self.fit.tracer_linear_light_profiles_to_light_profiles
@@ -99,7 +120,7 @@ class FitInterferometerPlotter(Plotter):
         """
         return TracerPlotter(
             tracer=self.tracer,
-            grid=self.fit.dataset.grid,
+            grid=self.fit.grid,
             mat_plot_2d=self.mat_plot_2d,
             visuals_2d=self.visuals_2d,
             include_2d=self.include_2d,
@@ -187,6 +208,66 @@ class FitInterferometerPlotter(Plotter):
         self.mat_plot_2d.output.subplot_to_figure(auto_filename="subplot_fit")
         self.close_subplot_figure()
 
+    def subplot_mappings_of_plane(self, plane_index: Optional[int] = None, auto_filename: str = "subplot_mappings"):
+
+        if self.fit.inversion is None:
+            return
+
+        plane_indexes = self.plane_indexes_from(plane_index=plane_index)
+
+        for plane_index in plane_indexes:
+            pixelization_index = 0
+
+            inversion_plotter = self.inversion_plotter_of_plane(plane_index=0)
+
+            inversion_plotter.open_subplot_figure(number_subplots=4)
+
+            self.figures_2d(dirty_image=True)
+
+            total_pixels = conf.instance["visualize"]["general"]["inversion"][
+                "total_mappings_pixels"
+            ]
+
+            pix_indexes = inversion_plotter.inversion.brightest_pixel_list_from(
+                total_pixels=total_pixels, filter_neighbors=True
+            )
+
+            inversion_plotter.visuals_2d.pix_indexes = [
+                [index] for index in pix_indexes[pixelization_index]
+            ]
+
+            inversion_plotter.visuals_2d.tangential_critical_curves = None
+            inversion_plotter.visuals_2d.radial_critical_curves = None
+
+            inversion_plotter.figures_2d_of_pixelization(
+                pixelization_index=pixelization_index, reconstructed_image=True
+            )
+
+            self.visuals_2d.pix_indexes = [
+                [index] for index in pix_indexes[pixelization_index]
+            ]
+
+            self.figures_2d_of_planes(
+                plane_index=plane_index,
+                plane_image=True,
+            )
+
+            self.set_title(label="Source Reconstruction (Unzoomed)")
+            self.figures_2d_of_planes(
+                plane_index=plane_index,
+                plane_image=True,
+                zoom_to_brightest=False,
+            )
+            self.set_title(label=None)
+
+            self.visuals_2d.pix_indexes = None
+
+            inversion_plotter.mat_plot_2d.output.subplot_to_figure(
+                auto_filename=f"{auto_filename}_{pixelization_index}"
+            )
+
+            inversion_plotter.close_subplot_figure()
+
     def figures_2d(
         self,
         data: bool = False,
