@@ -5,6 +5,4 @@ from autogalaxy.mock import *
 from autolens.imaging.mock.mock_fit_imaging import MockFitImaging
 from autolens.lens.mock.mock_tracer import MockTracer
 from autolens.lens.mock.mock_tracer import MockTracerPoint
-from autolens.analysis.mock.mock_result import MockResult
-from autolens.analysis.mock.mock_result import MockResults
 from autolens.point.mock.mock_point_solver import MockPointSolver
