@@ -1,9 +1,6 @@
-from autofit.plot.samples_plotters import SamplesPlotter
-from autofit.non_linear.nest.dynesty.plotter import DynestyPlotter
-from autofit.non_linear.nest.ultranest.plotter import UltraNestPlotter
-from autofit.non_linear.mcmc.emcee.plotter import EmceePlotter
-from autofit.non_linear.mcmc.zeus.plotter import ZeusPlotter
-from autofit.non_linear.optimize.pyswarms.plotter import PySwarmsPlotter
+from autofit.non_linear.plot.nest_plotters import NestPlotter
+from autofit.non_linear.plot.mcmc_plotters import MCMCPlotter
+from autofit.non_linear.plot.optimize_plotters import OptimizePlotter
 
 from autoarray.plot.wrap.base import (
     Units,
@@ -26,6 +23,7 @@ from autoarray.plot.wrap.base import (
 from autoarray.plot.wrap.one_d import YXPlot, FillBetween
 from autoarray.plot.wrap.two_d import (
     ArrayOverlay,
+    Contour,
     GridScatter,
     GridPlot,
     VectorYXQuiver,
@@ -73,6 +71,7 @@ from autogalaxy.plot.include.two_d import Include2D
 from autogalaxy.plot.visuals.one_d import Visuals1D
 from autogalaxy.plot.visuals.two_d import Visuals2D
 
+from autogalaxy.profiles.plot.basis_plotters import BasisPlotter
 from autogalaxy.profiles.plot.light_profile_plotters import LightProfilePlotter
 from autogalaxy.profiles.plot.light_profile_plotters import LightProfilePDFPlotter
 from autogalaxy.profiles.plot.mass_profile_plotters import MassProfilePlotter
@@ -85,7 +84,7 @@ from autogalaxy.imaging.plot.fit_imaging_plotters import FitImagingPlotter
 from autogalaxy.interferometer.plot.fit_interferometer_plotters import (
     FitInterferometerPlotter,
 )
-from autogalaxy.plane.plot.plane_plotters import PlanePlotter
+from autogalaxy.galaxy.plot.galaxies_plotters import GalaxiesPlotter
 from autogalaxy.galaxy.plot.adapt_plotters import AdaptPlotter
 
 from autolens.point.plot.point_dataset_plotters import PointDatasetPlotter
@@ -95,5 +94,6 @@ from autolens.interferometer.plot.fit_interferometer_plotters import (
     FitInterferometerPlotter,
 )
 from autolens.point.plot.fit_point_plotters import FitPointDatasetPlotter
-from autolens.lens.plot.ray_tracing_plotters import TracerPlotter
+from autolens.lens.plot.tracer_plotters import TracerPlotter
 from autolens.lens.subhalo import SubhaloPlotter
+from autolens.lens.sensitivity import SubhaloSensitivityPlotter
