@@ -8,7 +8,7 @@ from autogalaxy.plot.get_visuals import one_d as gv1d
 from autogalaxy.plot.get_visuals import two_d as gv2d
 
 from autolens.imaging.fit_imaging import FitImaging
-from autolens.lens.ray_tracing import Tracer
+from autolens.lens.tracer import Tracer
 
 
 class GetVisuals2D(gv2d.GetVisuals2D):
@@ -73,7 +73,7 @@ class GetVisuals2D(gv2d.GetVisuals2D):
         """
         origin = self.get("origin", value=aa.Grid2DIrregular(values=[grid.origin]))
 
-        border = self.get("border", value=grid.mask.derive_grid.border_sub_1.binned)
+        border = self.get("border", value=grid.mask.derive_grid.border)
 
         if border is not None and len(border) > 0 and plane_index > 0:
             border = tracer.traced_grid_2d_list_from(grid=border)[plane_index]
