@@ -3,16 +3,15 @@ from typing import Callable, Dict, Optional, Tuple
 import autofit as af
 import autogalaxy as ag
 
-from autogalaxy.analysis.analysis import Analysis as AgAnalysis
+from autogalaxy.analysis.analysis.analysis import Analysis as AgAnalysis
 
-from autolens.analysis.analysis import AnalysisLensing
-from autolens.analysis.visualizer import Visualizer
+from autolens.analysis.analysis.lens import AnalysisLens
+from autolens.analysis.plotter_interface import PlotterInterface
 from autolens.point.point_dataset import PointDict
 from autolens.point.fit_point.point_dict import FitPointDict
 from autolens.point.model.result import ResultPoint
 
 from autolens.point.point_solver import PointSolver
-from autolens.analysis.settings import SettingsLens
 
 from autolens import exc
 
@@ -24,14 +23,15 @@ except ModuleNotFoundError:
     NumbaException = ValueError
 
 
-class AnalysisPoint(AgAnalysis, AnalysisLensing):
+class AnalysisPoint(AgAnalysis, AnalysisLens):
+    Result = ResultPoint
+
     def __init__(
         self,
         point_dict: PointDict,
         solver: PointSolver,
         dataset=None,
         cosmology: ag.cosmo.LensingCosmology = ag.cosmo.Planck15(),
-        settings_lens=SettingsLens(),
     ):
         """
         The analysis performed for model-fitting a point-source dataset, for example fitting the point-sources of a
@@ -52,25 +52,17 @@ class AnalysisPoint(AgAnalysis, AnalysisLensing):
             visualization.
         cosmology
             The cosmology of the ray-tracing calculation.
-        settings_lens
-            Settings which control how the model-fit is performed.
         """
 
         super().__init__(cosmology=cosmology)
 
-        AnalysisLensing.__init__(
-            self=self, settings_lens=settings_lens, cosmology=cosmology
-        )
+        AnalysisLens.__init__(self=self, cosmology=cosmology)
 
         self.point_dict = point_dict
 
         self.solver = solver
         self.dataset = dataset
 
-    @property
-    def fit_func(self) -> Callable:
-        return self.fit_positions_for
-
     def log_likelihood_function(self, instance):
         """
         Determine the fit of the strong lens system of lens galaxies and source galaxies to the point source data.
@@ -86,14 +78,12 @@ class AnalysisPoint(AgAnalysis, AnalysisLensing):
             A fractional value indicating how well this model fit and the model masked_dataset itself
         """
         try:
-            fit = self.fit_positions_for(instance=instance)
+            fit = self.fit_from(instance=instance)
             return fit.log_likelihood
         except (AttributeError, ValueError, TypeError, NumbaException) as e:
             raise exc.FitException from e
 
-    def fit_positions_for(
-        self, instance, run_time_dict: Optional[Dict] = None
-    ) -> FitPointDict:
+    def fit_from(self, instance, run_time_dict: Optional[Dict] = None) -> FitPointDict:
         tracer = self.tracer_via_instance_from(
             instance=instance, run_time_dict=run_time_dict
         )
@@ -108,17 +98,9 @@ class AnalysisPoint(AgAnalysis, AnalysisLensing):
     def visualize(self, paths, instance, during_analysis):
         tracer = self.tracer_via_instance_from(instance=instance)
 
-        visualizer = Visualizer(visualize_path=paths.image_path)
+        plotter_interface = PlotterInterface(image_path=paths.image_path)
 
-    def make_result(
-        self,
-        samples: af.SamplesPDF,
-        model: af.Collection,
-        sigma=1.0,
-        use_errors=True,
-        use_widths=False,
-    ):
-        return ResultPoint(samples=samples, model=model, analysis=self)
-
-    def save_attributes_for_aggregator(self, paths: af.DirectoryPaths):
-        paths.save_object("dataset", self.point_dict)
+    def save_attributes(self, paths: af.DirectoryPaths):
+        self.point_dict.output_to_json(
+            file_path=paths._files_path / "point_dict.json", overwrite=True
+        )
