@@ -75,8 +75,8 @@ class AbstractPointSolver:
                 )
 
                 grid = grid_outside_distance_mask_from(
-                    distances_1d=distances_1d,
-                    grid_slim=grid,
+                    distances_1d=np.array(distances_1d),
+                    grid_slim=np.array(grid),
                     outside_distance=self.distance_to_mass_profile_centre,
                 )
 
@@ -180,8 +180,8 @@ class AbstractPointSolver:
         )
 
         grid_peaks = grid_peaks_from(
-            distance_1d=source_plane_distances,
-            grid_slim=grid,
+            distance_1d=np.array(source_plane_distances),
+            grid_slim=np.array(grid),
             neighbors=neighbors.astype("int"),
             has_neighbors=has_neighbors,
         )
@@ -232,8 +232,8 @@ class AbstractPointSolver:
         )
 
         grid_within_distance_of_centre = grid_within_distance(
-            distances_1d=source_plane_distances,
-            grid_slim=grid,
+            distances_1d=np.asarray(source_plane_distances),
+            grid_slim=np.asarray(grid),
             within_distance=distance,
         )
 
@@ -267,13 +267,13 @@ class PointSolver(AbstractPointSolver):
             resolution grid find its peak pixel.
 
          This process thus finds a set of 'peak' pixels and iteratively refines their values by locating them for
-         higher and higher resolution grids. The following occurances may happen during this process:
+         higher and higher resolution grids. The following occurrences may happen during this process:
 
           - A peak pixel may 'split' into multiple images. This is to be expected, when genuine multiple images
             were previously merged into one due to the grid being too low resolution.
 
           - Image pixels which do not correspond to genuine multiple images may be detected as they meet the peak
-            criteria. This can occurance in certain circumstances where a non-multiple image still traces closer than its
+            criteria. This can occurrence in certain circumstances where a non-multiple image still traces closer than its
             8 neighbors. Depending on how the `PositionFinder` is being used these can be removed.
         """
 
@@ -285,7 +285,7 @@ class PointSolver(AbstractPointSolver):
             distance_to_mass_profile_centre=distance_to_mass_profile_centre,
         )
 
-        self.grid = grid.binned
+        self.grid = grid
         self.pixel_scale_precision = pixel_scale_precision
 
     def refined_coordinates_from(
@@ -520,7 +520,7 @@ def pair_coordinate_to_closest_pixel_on_grid(coordinate, grid_slim):
 @aa.util.numba.jit()
 def grid_square_neighbors_1d_from(shape_slim):
     """
-    From a (y,x) grid of coordinates, determine the 8 neighors of every coordinate on the grid which has 8
+    From a (y,x) grid of coordinates, determine the 8 neighbors of every coordinate on the grid which has 8
     neighboring (y,x) coordinates.
 
     Neighbor indexes use the 1D index of the pixel on the masked grid counting from the top-left right and down.
