@@ -1,7 +1,7 @@
 import autoarray as aa
 import autogalaxy as ag
 
-from autolens.lens.ray_tracing import Tracer
+from autolens.lens.tracer import Tracer
 from autolens.analysis.result import Result
 
 
@@ -50,9 +50,9 @@ class ResultQuantity(Result):
         """
         An instance of a `Tracer` corresponding to the maximum log likelihood model inferred by the non-linear search.
 
-        If a dataset is fitted the adapt images of the adapt dataset must first be associated with each galaxy.
+        If a dataset is fitted the adapt images of the adapt image must first be associated with each galaxy.
         """
-        return self.analysis.tracer_via_instance_from(instance=self.instance_copy)
+        return self.analysis.tracer_via_instance_from(instance=self.instance)
 
     @property
     def max_log_likelihood_fit(self) -> ag.FitQuantity:
@@ -61,4 +61,4 @@ class ResultQuantity(Result):
         search.
         """
 
-        return self.analysis.fit_quantity_for_instance(instance=self.instance_copy)
+        return self.analysis.fit_quantity_for_instance(instance=self.instance)
