@@ -18,9 +18,7 @@ from autoarray.inversion.inversion.interferometer import (
     inversion_interferometer_util as inversion_interferometer,
 )
 from autoarray.operators import transformer_util as transformer
-from autogalaxy.analysis import model_util as model
 from autogalaxy.util import error_util as error
-from autogalaxy.plane import plane_util as plane
 from autogalaxy.analysis import chaining_util as chaining
 
-from autolens.lens import ray_tracing_util as ray_tracing
+from autolens.lens import tracer_util as tracer
